<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    //'#Active (Max #Available) Connections' => '',
    '#Connections in 5 minute intervals' => 'عدد الاتصالات في فواصل 5 دقائق',
    //'#Unique Guest Users' => '',
    '#Unique Users' => 'عدد المستخدمين الفرادى',
    '#Unique users and max #connections per day' => 'عدد المستخدمين الفرادى واقصى عدد الاتصالات في اليوم',
    'ACL Permission List' => 'قائمة الصلاحيات',
    'Account' => 'حساب',
    'Active' => 'نشط',
    'Active Configurations' => 'اعدادات نشطة',
    'Aggregated' => 'مجمع',
    'All' => 'الكل',
    'An application attempts to establish a VPN connection.' => 'يحاول تطبيق الاتصال مع الشبكة الخاصة الافتراضية.',
    'An error occurred.' => 'حدث خطأ ما.',
    'Application Usage' => 'استخدام التطبيق',
    'Approve' => 'وافق',
    'Approve Application' => 'الموافقة على التطبيق',
    //'Authentication Data' => '',
    'Authorized Applications' => 'التطبيقات المسموحة',
    'Authorized On' => 'مسموحة في',
    'Available Profiles' => 'مظاهر متاحة',
    'Block LAN' => 'منع الشبكة المحلية',
    'CA' => 'هيئة إصدار الشهادات',
    'CPU Usage:' => 'استعمال المعالج:',
    'Change Password' => 'تغيير كلمة المرور',
    'Configurations' => 'اعدادات',
    'Confirm' => 'مصادقة',
    'Connected' => 'متصل',
    'Connections' => 'اتصالات',
    'Created On' => 'منشأة في',
    'Current Password' => 'كلمة المرور الحالية',
    'Current Password not correct!' => 'كلمة المرور الحالية غير صحيحة!',
    'Currently there are no clients connected to this profile.' => 'لا يوجد عملاء متصلون بهذا المظهر حاليا.',
    'DNS Search Domain(s)' => 'نطاق البحث على الخوادم',
    'DNS Server(s)' => 'خوادم أسماء النطاقات',
    'Danger Zone' => 'منطقة خطر',
    'Date/Time' => 'التاريخ/الوقت',
    'Default Gateway' => 'البوابة الافتراضية',
    'Delete' => 'حذف',
    'Delete Account' => 'حذف الحساب',
    'Delete Account Data' => 'حذف بيانات الحساب',
    'Disable Account' => 'تعطيل الحساب',
    'Disabled' => 'معطل',
    'Disconnected' => 'غير متصل',
    'Distribution of unique users over the VPN applications.' => 'توزيع المستخدمين الفرادى على تطبيقات الشبكة الخاصة الافتراضية.',
    'Download' => 'تحميل',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'تحميل اعدادات الشبكة الخاصة الافتراضية غير مسموح. المرجو استعمال التطبيق.',
    'Enable Account' => 'تفعيل الحساب',
    'Error' => 'خطأ',
    'Excluded Route(s)' => 'وجهات مستبعدة',
    'Expires On' => 'ينتهي في',
    'Export (CSV)' => 'تصدير (قيم مفصولة بفواصل)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'جد هوية المستخدم الذي استعمل عنوانا ما من نظام الشبكات من الجيل الرابع او السادس عند نقطة في الزمن.',
    'Fingerprint' => 'بصمة',
    'Here you can change the password for your account.' => 'يمكنك هنا تغيير كلمة مرور حسابك.',
    'Home' => 'الصفحة الرئيسية',
    'Hostname' => 'اسم المضيف',
    'IP Address' => 'عنوان نظام الشبكات',
    'IPs' => 'عناوين نظام الشبكات',
    'IPv4 Prefix' => 'بادئة IPv4',
    'IPv6 Prefix' => 'بادئة IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'استورد او انسخ/الصق هذا الاعداد لتطبيق وايرجارد.',
    'Info' => 'معلومات',
    'Issues' => 'مشاكل',
    'Live' => 'مباشر',
    'Log' => 'سجل',
    //'MTU' => '',
    'Max #Connections' => 'اقصى عدد الاتصالات',
    'More' => 'مزيد',
    'N/A' => 'لا ينطبق',
    'Name' => 'اسم',
    'New Configuration' => 'اعداد جديد',
    'New Password' => 'كلمة مرور جديدة',
    'New Password (confirm)' => 'كلمة مرور جديدة (تأكيد)',
    'New Password and New Password (confirm) MUST match!' => 'كلمة مرور جديدة و كلمة مرور جديدة (تأكيد) يجب أن يتطابقا!',
    'No Permission(s)' => 'لا صلاحيات',
    'No VPN profiles are available for your account.' => 'لا مظاهر للشبكة الخاصة الافتراضية متاحة لحسابك.',
    'Node URL' => 'موقع العقدة',
    'Node(s)' => 'عقد(ة)',
    'OAuth' => 'ميثاق أوث',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'احصل على ملف اعداد الشبكة الخاصة الافتراضية  جديد لاستخدامه في عميل الشبكة الخاصة الافتراضية الخاص بك.',
    'Offered Ports' => 'منافذ متاحة',
    'Offline' => 'خارج الشبكة',
    'Online' => 'على الشبكة',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'وافق فقط عندما تحاول الاتصال بالشبكة الخاصة الافتراضية عبر هذا التطبيق!',
    'OpenVPN' => 'OpenVPN',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'سجل خادم OpenVPN',
    'Password' => 'كلمة المرور',
    'Permissions' => 'صلاحيات',
    'Please sign in with your username and password.' => 'سجل دخولك من فضلك باستعمال اسم المستخدم وكلمة المرور.',
    'Port' => 'منفذ',
    'Ports' => 'منافذ',
    'Preferred Protocol' => 'الميثاق المفضل',
    'Profile' => 'مظهر',
    //'Profile ID' => '',
    'Profile Usage' => 'استعمال المظهر',
    'Profile(s)' => 'المظاهر',
    'Public Key' => 'مفتاح عام',
    //'Refresh' => '',
    'Results' => 'نتائج',
    'Revoke' => 'سحب',
    'Route(s)' => 'وجهات',
    'Search' => 'ابحث',
    'Select a profile and choose a name, e.g. "Phone".' => 'اختر مظهرا و إسما، مثال "الهاتف".',
    'Server' => 'خادم',
    'Sign In' => 'سجل الدخول',
    'Sign Out' => 'سجل الخروج',
    'Stats' => 'احصائيات',
    'The <em>Date/Time</em> MUST be in UTC.' => '.يجب ان يكون بالتوقيت العالمي </em>التاريخ/الوقت<em>',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'يقبل حقل </em>التاريخ/الوقت<em> التواريخ على شكل <code>Y-m-d H:i:s</code> ، مثلا <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'بيانات الاعتماد التي قدمتها غير صحيحة.',
    'The list of applications you authorized to create a VPN connection.' => 'لائحة التطبيقات المخولة لانشاء اتصال بالشبكة الخاصة الافتراضية.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'اقصى عدد عملاء الشبكة الخاصة الافتراضية المتصلة في آن واحد خلال الاسبوع الماضي',
    'The most recent VPN connections with this account.' => 'أحدث اتصالات الشبكة الخاصة الافتراضية من هذا الحساب.',
    //'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => '',
    //'The number of unique guest users connecting to the VPN service in the last week' => '',
    'The number of unique users connecting to the VPN service in the last week' => 'عدد المستخدمين الفرادى الذين اتصلوا بخدمة الشبكة الخاصة الافتراضية في الاسبوع الماضي',
    'The table below shows the per profile VPN usage over the last week.' => 'يوضح الجدول ادناه استخدام الشبكة الخاصة الافتراضية حسب كل مظهر خلال الاسبوع الماضي.',
    'There are no results matching your criteria.' => 'لا توجد نتائج مطابقة لهذه المعايير.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'يتم استخدام مصدر خارجي للمصادقة. حذف بيانات الحساب لن يمنع المستخدم من الدخول (مجددا).',
    'This user does not have any active configurations.' => 'هذا المستخدم ليس لديه اي اعدادات نشطة.',
    'This user does not have any connections.' => 'هذا المستخدم ليس لديه اي اتصالات.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'لمنع التطبيقات الضارة من الاتصال بالشبكة الخاصة الافتراضية نيابة عنك، عليك الموافقة  صراحة على هذا التطبيق اولا.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'استخدم تطبيق وايرجارد على جوالك لمسح رمز الاستجابة السريعة.',
    'User ID' => 'هوية المستخدم',
    'Username' => 'اسم المستخدم',
    'Users' => 'المستخدمين',
    'VPN Portal' => 'بوابة الشبكة الخاصة الافتراضية',
    'Version' => 'اصدار',
    'Welcome to this VPN service!' => 'مرحبا بك على خدمة الشبكة الخاصة الافتراضية هذه!',
    'Why is this necessary?' => 'لم هذا ضروري؟',
    'WireGuard' => 'وايرجارد',
    'WireGuard Configuration' => 'اعداد وايرجارد',
    'You can download the detailed VPN usage statistics below.' => 'يمكنك تحميل إحصائيات مفصلة حول استخدام الشبكة الخاصة الافتراضية أدناه.',
    'You cannot manage your own user account.' => 'لا يمكنك إدارة حساب المستخدم الخاص بك.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'لقد بلغت الحد الأقصى من اعدادات الشبكة الخاصة الافتراضية النشطة المسموح بها. احذف بعضها أولاً.',
    'Your account does not have access to any VPN profile.' => 'ليس لحسابك حق الولوج للشبكة الخاصة الافتراضية.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'تنتهي صلاحية الاعداد الجديد عند %expiryDate%. عد هنا للحصول على اعداد جديد بعد انتهاء الصلاحية!',
];
